# NiChart_common_utils

This repo contains basic utilities that can be used across NiChart software tools. For example, the logic used to automatically detect MRIDs /sessions from collections of files.

When possible, software tools should require this package and use this logic to do these common tasks.

